bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.broadcasting_multiplier
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamily.broadcasting_multiplier